import time
from attendance_gl_src import Attendance_In_Excel as aie
from attendance_gl_src import Excel_To_Html as eth
# import Attendance_In_Excel as aie
# import Excel_To_Html as eth

def main():
    aie.retrieve_network_info()
    time.sleep(2)
    eth.create_html_calendar()

if __name__ == "__main__":
    main()



import win32com.client
from datetime import datetime
from pathlib import Path
import configparser

executable_path = config_path = Path(__file__).resolve().parent.parent.parent.parent / 'Scripts' / 'markatt.exe'
print(f'Executable path: {executable_path}')

def main():
    config = configparser.ConfigParser()
    config_path = Path(__file__).resolve().parent / 'resources' / 'config.properties'
    config.read(config_path)
    schedule_list = config['data']['scheduled.time'].split(',')
    print(f'Scheduled time: {schedule_list}')
    for time in schedule_list:
        start_hour = int(time.split(':')[0])
        start_minute = int(time.split(':')[1])
        start_time = datetime.now().replace(hour=start_hour, minute=start_minute, second=0, microsecond=0)
        task_name = "GL_Attendance_"+str(start_hour)+"_"+str(start_minute)
        scheduleTask(task_name, start_time)


def scheduleTask(task_name, start_time):
    print(f"Scheduling task..... {task_name}..............")
    scheduler = win32com.client.Dispatch('Schedule.Service')
    scheduler.Connect()

    root_folder = scheduler.GetFolder('\\')
    task_def = scheduler.NewTask(0)

    # Create a trigger
    trigger = task_def.Triggers.Create(2)  # 2 means a daily trigger
    trigger.StartBoundary = start_time.strftime('%Y-%m-%dT%H:%M:%S')
    trigger.Repetition.Interval = "P1D"  # Repeat every day
    trigger.Repetition.Duration = "P1D"  # Repeat indefinitely

    # Create the action to run the executable
    action = task_def.Actions.Create(0)  # 0 means execute action
    action.Path = str(executable_path)

    # Set task parameters
    task_def.RegistrationInfo.Description = f'{task_name} - Run daily at {start_time.strftime("%H:%M")}'
    task_def.Settings.Enabled = True
    task_def.Settings.StartWhenAvailable = True  # Ensures the task runs if missed
    task_def.Settings.Hidden = False
    task_def.Settings.DisallowStartIfOnBatteries = False
    task_def.Settings.StopIfGoingOnBatteries = False
    task_def.Settings.WakeToRun = True  # Wake the computer to run the task

    # Register the task
    root_folder.RegisterTaskDefinition(
        task_name,
        task_def,
        6,  # TASK_CREATE_OR_UPDATE
        None,  # No user
        None,  # No password
        3,  # TASK_LOGON_INTERACTIVE_TOKEN
        None
    )
    print(f"Scheduled task '{task_name}' to run {executable_path} daily at {start_time.strftime('%H:%M')}.")

if __name__ == "__main__":
    main() 



import pandas as pd
import json
import configparser
from pathlib import Path
import logging
import logging.config

# Load logging configuration from the file
logging.config.fileConfig(Path(__file__).resolve().parent / 'resources' / 'logging.conf', disable_existing_loggers=False)
logger = logging.getLogger(__name__)

def create_html_calendar():
    logger.info("############################### Creating HTML Calendar ###############################")

    #get the directory path from the config file
    config = configparser.ConfigParser()
    config_path = Path(__file__).resolve().parent / 'resources' / 'config.properties'
    config.read(config_path)
    directory = config['data']['dir.path']
    fileName = config['data']['attendance_excel_name']

    # Read the Excel file
    df = pd.read_excel(directory + fileName)

    # Convert datetime objects to strings
    df['Date'] = df['Date'].dt.strftime('%Y-%m-%d')

    # Convert the dataframe to a dictionary
    data = df.to_dict(orient='records')

    # Convert the data to JSON format
    json_data = json.dumps(data)

    # Prepare the HTML content
    html_content = f"""
    <!DOCTYPE html>
    <html lang="en">
    <head>
        <meta charset="UTF-8">
        <meta name="viewport" content="width=device-width, initial-scale=1.0">
        <title>Calendar</title>
        <style>
            body {{ font-family: Arial, sans-serif; }}
            .calendar {{ display: table; width: 100%; max-width: 600px; margin: 0 auto; border-collapse: collapse; }}
            .calendar th, .calendar td {{ border: 1px solid #999; padding: 10px; text-align: center; }}
            .calendar th {{ background-color: #f2f2f2; }}
            .calendar .green {{ background-color: green; color: white; }}
            .calendar .LightBlue {{ background-color: LightBlue; color: white; }}
            .calendar-title {{ text-align: center; font-size: 1.5em; margin-bottom: 10px; }}
            .navigation-buttons {{ text-align: center; margin-bottom: 10px; }}
        #header {{
            background-color: #f37038;
            color: white;
            text-align: center;
            padding: 10px;
             margin-bottom: 50px;
        }}
        #logo {{
            display: block;
            margin-left: auto;
            margin-right: auto;
            width: 50%;
        }}
        </style>
    </head>
    <body>
     <div id="header">
        <img src="https://www.globallogic.com/wp-content/uploads/2021/07/Logo_GL-Hitachi_White-web.svg" class="custom-logo svg-logo-desktop" width="196" height="45" alt="GlobalLogic India" title="GlobalLogic-Logo-White | GlobalLogic">
        <h1>Attendance Report</h1>
    </div>
        <div class="navigation-buttons">
            <button id="prevButton" style="background-color: #f37038; color: white;">Previous</button>
            <span id="monthYear" style="font-weight: bold;"></span>
            <button id="nextButton" style="background-color: #f37038; color: white;">Next</button>
        </div>
        <div id="calendarContainer"></div>
        <script>
            const data = {json_data};

            function createCalendar(year, month) {{
                const calendarDiv = document.getElementById('calendarContainer');
                calendarDiv.innerHTML = '';

                const monthNames = ['January', 'February', 'March', 'April', 'May', 'June', 'July', 'August', 'September', 'October', 'November', 'December'];
                const dayNames = ['Sun', 'Mon', 'Tue', 'Wed', 'Thu', 'Fri', 'Sat'];

                const monthYearSpan = document.getElementById('monthYear');
                monthYearSpan.innerText = monthNames[month] + ' ' + year;

                const table = document.createElement('table');
                table.className = 'calendar';

                const header = document.createElement('thead');
                const headerRow = document.createElement('tr');
                dayNames.forEach(day => {{
                    const th = document.createElement('th');
                    th.innerText = day;
                    headerRow.appendChild(th);
                }});
                header.appendChild(headerRow);
                table.appendChild(header);

                const body = document.createElement('tbody');
                const firstDay = new Date(year, month, 1).getDay();
                const daysInMonth = new Date(year, month + 1, 0).getDate();

                let date = 1;
                for (let i = 0; i < 6; i++) {{
                    const row = document.createElement('tr');
                    for (let j = 0; j < 7; j++) {{
                        const cell = document.createElement('td');
                        if (i === 0 && j < firstDay) {{
                            cell.innerText = '';
                        }} else if (date > daysInMonth) {{
                            break;
                        }} else {{
                            const currentDate = new Date(year, month, date);
                            const dateString = currentDate.getFullYear() + 
                                '-' + (currentDate.getMonth() + 1).toString().padStart(2, '0') + 
                                '-' + currentDate.getDate().toString().padStart(2, '0');

                            cell.innerText = date;
                            if (data.some(item => item.Date.split(' ')[0] === dateString && item.Office)) {{
                                cell.className = 'green';
                            }}

                            // Check if the day is Saturday or Sunday
                            const dayOfWeek = currentDate.getDay();
                            if (dayOfWeek === 0 || dayOfWeek === 6) {{
                                cell.className = 'LightBlue';
                            }}

                            // Check if the date is today's date
                            const today = new Date();
                            if (currentDate.getDate() === today.getDate() && currentDate.getMonth() === today.getMonth() && currentDate.getFullYear() === today.getFullYear()) {{
                                cell.style.border = '2px solid red';
                            }}

                            date++;
                        }}
                        row.appendChild(cell);
                    }}
                    body.appendChild(row);
                }}
                table.appendChild(body);
                calendarDiv.appendChild(table);
            }}

            function loadCalendar() {{
                const today = new Date();
                let year = today.getFullYear();
                let month = today.getMonth();

                createCalendar(year, month);

                const prevButton = document.getElementById('prevButton');
                const nextButton = document.getElementById('nextButton');

                prevButton.onclick = () => {{
                    if (month === 0) {{
                        month = 11;
                        year--;
                    }} else {{
                        month--;
                    }}
                    createCalendar(year, month);
                }};

                nextButton.onclick = () => {{
                    if (month === 11) {{
                        month = 0;
                        year++;
                    }} else {{
                        month++;
                    }}
                    createCalendar(year, month);
                }};
            }}

            document.addEventListener('DOMContentLoaded', loadCalendar);
        </script>
    </body>
    </html>
    """

    # Save the HTML content to a file
    logger.info("Creating calendar.html file...")
    with open(directory + 'calendar.html', 'w') as file:
        file.write(html_content)
    logger.info("calendar.html file created successfully!")



import os
from pathlib import Path
import logging
import logging.config
from logging.handlers import RotatingFileHandler
from datetime import datetime

class SafeRotatingFileHandler(RotatingFileHandler):
    def __init__(self, filename, mode='a', maxBytes=0, backupCount=0, encoding=None, delay=False, errors=None):
        #get the directory path from of the package to put log file
        config_path = Path(__file__).resolve().parent
        date_str = datetime.now().strftime('%Y-%m-%d')
        filePath = config_path.__str__() + '\\logs\\' + filename + '_' + date_str
        # Ensure the directory exists
        os.makedirs(os.path.dirname(filePath), exist_ok=True)

        super().__init__(filePath, mode, maxBytes, backupCount, encoding, delay, errors)

                # Add blank lines to separate logs from previous runs
        self._add_blank_lines()

    def _add_blank_lines(self, num_lines=5):
        with open(self.baseFilename, 'a', encoding=self.encoding) as log_file:
            log_file.write('\n' * num_lines)



from setuptools import setup, find_packages

setup(
    name='Attendance_GL',
    version='1.0.0', 
    description='A Python package to track attendance in an Excel file and convert it to an HTML file', 
    author='Ankush Sawant', 
    author_email='qaankush@gmail.com', 
    packages=find_packages(),
   # package_dir={'': 'attendance_gl_src'},
    include_package_data=True,
    package_data={
        '': ['resources/*.conf', 'resources/*.properties'],
    },
    install_requires=[
        'openpyxl',
        'pandas', 
        'configparser',
    ],
    entry_points={
        'console_scripts': [
            'markatt=attendance_gl_src.Runner:main', 
            'scheduleatt=attendance_gl_src.Task_Scheduler:main', 
        ],
    },
)


import os
from openpyxl import Workbook, load_workbook
from datetime import date
import subprocess
import configparser
from pathlib import Path
import logging
import logging.config

# Load logging configuration from the file
logging.config.fileConfig(Path(__file__).resolve().parent / 'resources' / 'logging.conf', disable_existing_loggers=False)
logger = logging.getLogger(__name__)


def retrieve_network_info():
    # Load logging configuration from the file
    logger.info("############################### Marking Attendance ###############################")

    # get the directory path from the config file
    config = configparser.ConfigParser()
    config_path = Path(__file__).resolve().parent / 'resources' / 'config.properties'
    logger.info(f'config path: {config_path}')
    config.read(config_path)
    directory = config['data']['dir.path']
    fileName = config['data']['attendance_excel_name']
    office_networks_list = config['data']['possible.networks']


    # Ensure the directory exists
    if not os.path.exists(directory):
        logger.info(f"Creating directory: {directory}")
        os.makedirs(directory)

    # Now the file path should be correct
    file_path = os.path.join(directory, fileName)

    # using the check_output() for having the network term retrieval 
    devices = subprocess.check_output(['netsh', 'wlan', 'show', 'network']) 

    # decode it to strings 
    try:
        devices = devices.decode('utf-8')
    except UnicodeDecodeError as e:
        logger.error(f"Error in decoding bytes: {e}")
        # Handle the error by ignoring or replacing problematic bytes
        devices = devices.decode('utf-8', errors='replace')
    devices = devices.replace("\r", "") 
    logger.info(f'Networks found: {devices.title()}')

    # if any of the given name is present then you are in office
    office_network_names = list(map(str.strip, office_networks_list.split(',')))
    office_network = any(name.lower() in devices.lower() for name in office_network_names)

    if not os.path.exists(file_path):
        wb = Workbook()
        ws = wb.active
        ws.title = "Sheet1"
        ws.append(['Date', 'Office'])
    else:
        wb = load_workbook(filename=file_path)
        ws = wb.active

    # Check if today's date is already present and if column B value is True
    for row in ws.iter_rows(min_row=2, values_only=True):
        date_from_row = row[0].date() #fetch the date from default coming datetime object
        if date_from_row == date.today():
            if row[1] == True:
                logger.info("Attendance already marked for today as Present!")
                return
            else:
                logger.info("Attendance was marked as Absent! Deleting the row to update the status.")
                ws.delete_rows(ws.max_row)
                break
        
    ws.append([date.today(), office_network])
    logger.info(f"Attendance marked for {date.today()} as {'Present' if office_network else 'Absent'}")
    try:
        wb.save(file_path)
    except Exception as e:
        logger.error("Error saving the file")
        logger.error(e)
